@@ -90,7 +90,7 @@ Killbots::RulesetSelector::RulesetSelector(QWidget *parent)
     boxLayout->setRowStretch(5, 10);
 
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(kcfg_Ruleset);
     layout->addWidget(m_listWidget);
     layout->addWidget(groupBox, 10);
@@ -144,7 +144,7 @@ void Killbots::RulesetSelector::findRulesets()
     m_listWidget->setMaximumHeight(itemHeight * m_listWidget->count() + verticalMargin);
 }
 
-void Killbots::RulesetSelector::selectionChanged(QString rulesetName)
+void Killbots::RulesetSelector::selectionChanged(const QString &rulesetName)
 {
     const Ruleset *ruleset = m_rulesetMap.value(rulesetName);
 
